@@ -22,8 +22,8 @@
   options("tern.arrow.start"           = 0.3)
   options("tern.arrow.finish"          = 0.7)
   options('tern.arrowsep'              = 0.1)
-  options('tern.vshift'                = unit(0,'npc'))
-  options('tern.hshift'                = unit(0,'npc'))
+  options('tern.vshift'                = 0.0)
+  options('tern.hshift'                = 0.0)
   options("tern.showarrows"            = TRUE)
   options("tern.showgrid.major"        = TRUE)
   options("tern.showgrid.minor"        = TRUE)
