@@ -115,6 +115,8 @@ strip_unapproved <- function(layers){
                         Tmark            = "GeomTmark",
                         Lmark            = "GeomLmark",
                         Rmark            = "GeomRmark",
+                        point_swap       = "GeomPointSwap",
+                        "GeomRasterAnnTern",
                         "GeomDl"
 )
 
