@@ -30,7 +30,7 @@
 #' tern.panel.grid tern.panel.grid.major tern.panel.grid.major.T tern.panel.grid.major.L tern.panel.grid.major.R 
 #' tern.panel.grid.minor.show tern.panel.grid.minor 
 #' tern.panel.grid.minor.T tern.panel.grid.minor.L tern.panel.grid.minor.R ternary.options
-#' panel.margin.tern tern.panel.expand tern.panel.rotate tern.panel.grids.ontop
+#' panel.margin.tern tern.panel.expand tern.panel.rotate tern.panel.grid.ontop tern.panel.border.ontop
 #' tern.axis.text.show
 #' @name theme_elements
 NULL
@@ -54,7 +54,8 @@ ggint$.element_tree$tern.axis.clockwise            = .el_def("logical",
 ggint$.element_tree$tern.axis.line                 = .el_def("element_line", "tern.axis",            description="Base Line") #
 ggint$.element_tree$tern.axis.line.T               = .el_def("element_line", "tern.axis.line",       description="Line for TOP Axis") #
 ggint$.element_tree$tern.axis.line.L               = .el_def("element_line", "tern.axis.line",       description="Line for LHS Axis") #
-ggint$.element_tree$tern.axis.line.R               = .el_def("element_line", "tern.axis.line",       description="LIne for RHS Axis") #
+ggint$.element_tree$tern.axis.line.R               = .el_def("element_line", "tern.axis.line",       description="Line for RHS Axis") #
+ggint$.element_tree$tern.axis.line.ontop           = .el_def("logical",                              description="Bring Axis Borders on Top of Everything")
 
 #Axis Titles
 ggint$.element_tree$tern.axis.title                = .el_def("element_text", "tern.axis.text",       description="Base Apex Title") #
@@ -112,6 +113,6 @@ ggint$.element_tree$tern.panel.grid.minor.T        = .el_def("element_line", "te
 ggint$.element_tree$tern.panel.grid.minor.L        = .el_def("element_line", "tern.panel.grid.minor",description="Minor Gridline for LHS Axis") #
 ggint$.element_tree$tern.panel.grid.minor.R        = .el_def("element_line", "tern.panel.grid.minor",description="Minor Gridline for RHS Axis") #
 ggint$.element_tree$tern.panel.grid.minor.show     = .el_def("logical",                              description="Show or Hide Minor Gridline")
-ggint$.element_tree$tern.panel.grid.ontop          = .el_def("logical",                              description="The amount to expand the ternary plotting panel, in ratio to npc units")
+ggint$.element_tree$tern.panel.grid.ontop          = .el_def("logical",                              description="Bring grids on top of everything else")
 ggint$.element_tree$tern.panel.expand              = .el_def("numeric",                              description="The amount to expand the ternary plotting panel, in ratio to npc units")
 ggint$.element_tree$tern.panel.rotate              = .el_def("numeric",                              description="The amount to rotate the ternary diagram in degrees")
